Module: Geoblacklight Deprecated
- Defined in:
- lib/geoblacklight/faraday_middleware/follow_redirects.rb,
lib/geoblacklight.rb,
lib/geoblacklight/engine.rb,
lib/geoblacklight/routes.rb,
lib/geoblacklight/version.rb,
lib/geoblacklight/download.rb,
lib/geoblacklight/geometry.rb,
lib/geoblacklight/metadata.rb,
lib/geoblacklight/constants.rb,
lib/geoblacklight/reference.rb,
lib/geoblacklight/wms_layer.rb,
lib/geoblacklight/exceptions.rb,
lib/geoblacklight/references.rb,
lib/geoblacklight/routes/wms.rb,
lib/geoblacklight/item_viewer.rb,
lib/geoblacklight/bounding_box.rb,
lib/geoblacklight/metadata/base.rb,
lib/geoblacklight/metadata/fgdc.rb,
lib/geoblacklight/metadata/html.rb,
lib/geoblacklight/metadata/iso19139.rb,
lib/geoblacklight/routes/exportable.rb,
lib/geoblacklight/relation/ancestors.rb,
lib/geoblacklight/routes/downloadable.rb,
lib/geoblacklight/metadata_transformer.rb,
lib/geoblacklight/relation/descendants.rb,
lib/geoblacklight/view_helper_override.rb,
lib/geoblacklight/download/hgl_download.rb,
lib/geoblacklight/download/kmz_download.rb,
lib/geoblacklight/deprecated_configuration.rb,
lib/geoblacklight/download/geojson_download.rb,
lib/geoblacklight/download/geotiff_download.rb,
lib/geoblacklight/metadata_transformer/base.rb,
lib/geoblacklight/metadata_transformer/fgdc.rb,
lib/geoblacklight/relation/relation_response.rb,
lib/generators/geoblacklight/assets_generator.rb,
lib/geoblacklight/download/shapefile_download.rb,
lib/generators/geoblacklight/install_generator.rb,
app/models/concerns/geoblacklight/solr_document.rb,
app/presenters/geoblacklight/document_presenter.rb,
lib/geoblacklight/metadata_transformer/iso19139.rb,
app/presenters/geoblacklight/bbox_item_presenter.rb,
lib/geoblacklight/wms_layer/feature_info_response.rb,
app/components/geoblacklight/display_note_component.rb,
app/models/concerns/geoblacklight/bbox_filter_field.rb,
app/models/concerns/geoblacklight/bbox_filter_query.rb,
app/models/concerns/geoblacklight/solr_document/carto.rb,
app/components/geoblacklight/icon_facet_item_component.rb,
app/models/concerns/geoblacklight/solr_document/arcgis.rb,
app/models/concerns/geoblacklight/solr_document/finder.rb,
app/helpers/geoblacklight/geoblacklight_helper_behavior.rb,
app/models/concerns/geoblacklight/solr_document/citation.rb,
app/models/concerns/geoblacklight/solr_document/inspection.rb,
app/components/geoblacklight/homepage_feature_facet_component.rb,
app/models/concerns/geoblacklight/suppressed_records_search_behavior.rb
Overview
This module is removed in GeoBlacklight 5. Search result presentation moved to Geoblacklight::SearchResultComponent.
Adds helper behavior logic for GeoBlacklight, to used alongside BlacklightHelperBehavior
Defined Under Namespace
Modules: Constants, DeprecatedConfiguration, Exceptions, FaradayMiddleware, GeoblacklightHelperBehavior, Metadata, MetadataTransformer, Relation, Routes, SolrDocument, SuppressedRecordsSearchBehavior, ViewHelperOverride Classes: AssetsGenerator, BboxFilterField, BboxFilterQuery, BboxItemPresenter, BoundingBox, DisplayNoteComponent, DocumentPresenter, Download, Engine, FeatureInfoResponse, GeojsonDownload, Geometry, GeotiffDownload, HglDownload, HomepageFeatureFacetComponent, IconFacetItemComponent, Install, ItemViewer, KmzDownload, Reference, References, ShapefileDownload, WmsLayer
Constant Summary collapse
- VERSION =
"4.6.0"
Class Method Summary collapse
-
.deprecation ⇒ Object
Deprecator for GeoBlacklight's own deprecations.
- .logger ⇒ Object
Class Method Details
.deprecation ⇒ Object
Deprecator for GeoBlacklight's own deprecations. Anything deprecated here is slated for removal in GeoBlacklight 5.0.
Downstream applications can configure its behavior the same way they would any other Rails deprecator, e.g. in config/application.rb:
config.active_support.deprecation = :raise
or directly:
Geoblacklight.deprecation.behavior = :silence
19 20 21 |
# File 'lib/geoblacklight.rb', line 19 def self.deprecation @deprecation ||= ActiveSupport::Deprecation.new("5.0", "GeoBlacklight") end |
.logger ⇒ Object
54 55 56 |
# File 'lib/geoblacklight.rb', line 54 def self.logger ::Rails.logger end |