Class: Geoblacklight::Reference
- Inherits:
-
Object
- Object
- Geoblacklight::Reference
- Defined in:
- lib/geoblacklight/reference.rb
Overview
Parses an array of dct_references to create useful reference information
Instance Attribute Summary collapse
-
#reference ⇒ Object
readonly
Returns the value of attribute reference.
Instance Method Summary collapse
-
#endpoint ⇒ String
The endpoint URL for a Geoblacklight::Reference.
-
#initialize(reference) ⇒ Reference
constructor
Initializes a Reference object using an Array.
-
#to_hash ⇒ Hash
Creates a hash, using its type as key and endpoint as value.
-
#type ⇒ Symbol
Lookups the type from the Constants::URI using the reference’s URI.
Constructor Details
#initialize(reference) ⇒ Reference
Initializes a Reference object using an Array
11 12 13 |
# File 'lib/geoblacklight/reference.rb', line 11 def initialize(reference) @reference = reference end |
Instance Attribute Details
#reference ⇒ Object (readonly)
Returns the value of attribute reference.
6 7 8 |
# File 'lib/geoblacklight/reference.rb', line 6 def reference @reference end |
Instance Method Details
#endpoint ⇒ String
The endpoint URL for a Geoblacklight::Reference
18 19 20 |
# File 'lib/geoblacklight/reference.rb', line 18 def endpoint @reference[1] end |
#to_hash ⇒ Hash
Creates a hash, using its type as key and endpoint as value
32 33 34 |
# File 'lib/geoblacklight/reference.rb', line 32 def to_hash { type => endpoint } end |
#type ⇒ Symbol
Lookups the type from the Constants::URI using the reference’s URI
25 26 27 |
# File 'lib/geoblacklight/reference.rb', line 25 def type Geoblacklight::Constants::URI.key(uri) end |