Module: Geoblacklight::SolrDocument::Carto Deprecated

Included in:
Geoblacklight::SolrDocument
Defined in:
app/models/concerns/geoblacklight/solr_document/carto.rb

Overview

Deprecated.

The Carto OneClick integration is removed without replacement in GeoBlacklight 5. Remove the :carto show tools partial from your CatalogController before upgrading.

Module for providing external Carto download references for a document

Instance Method Summary collapse

Instance Method Details

#carto_referenceString

Deprecated.

Returns a url to a file that should be used with CartoDB integration

Returns:

  • (String)


16
17
18
19
# File 'app/models/concerns/geoblacklight/solr_document/carto.rb', line 16

def carto_reference
  return unless public? && download_types.try(:[], :geojson).present?
  Geoblacklight::GeojsonDownload.new(self).url_with_params
end