Class: Geoblacklight::Configuration

Inherits:
Object
  • Object
show all
Includes:
ActiveModel::Attributes
Defined in:
lib/geoblacklight/configuration.rb,
lib/geoblacklight/configuration/layer_config.rb,
lib/geoblacklight/configuration/fields_config.rb,
lib/geoblacklight/configuration/leaflet_config.rb,
lib/geoblacklight/configuration/settings_builder.rb,
lib/geoblacklight/configuration/relationship_config.rb,
lib/geoblacklight/configuration/leaflet_sleep_config.rb,
lib/geoblacklight/configuration/relationships_config.rb,
lib/geoblacklight/configuration/leaflet_layers_config.rb,
lib/geoblacklight/configuration/default_settings_builder.rb,
lib/geoblacklight/configuration/case_insensitive_settings.rb,
lib/geoblacklight/configuration/display_note_shown_config.rb

Overview

Configuration for Geoblacklight

Defined Under Namespace

Classes: CaseInsensitiveSettings, DefaultSettingsBuilder, DisplayNoteShownConfig, FieldsConfig, LayerConfig, LeafletConfig, LeafletLayersConfig, LeafletSleepConfig, RelationshipConfig, RelationshipsConfig, SettingsBuilder

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeConfiguration

Returns a new instance of Configuration.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/geoblacklight/configuration.rb', line 53

def initialize
  super
  @relationships_shown = RelationshipsConfig.new
  @gbl_params = [
    :bbox, :email, :file, :format, :id, :logo, :provider, :type,
    :BBOX, :HEIGHT, :LAYERS, :QUERY_LAYERS, :URL, :WIDTH, :X, :Y
  ]
  @wms_params = {
    SERVICE: "WMS",
    VERSION: "1.1.1",
    REQUEST: "GetFeatureInfo",
    STYLES: "",
    SRS: "EPSG:4326",
    EXCEPTIONS: "application/json",
    INFO_FORMAT: "application/json"
  }
  @help_text = {
    viewer_protocol: %w[
      cog
      dynamic_map_layer
      feature_layer
      iiif
      iiif_manifest
      image_map_layer
      index_map
      oembed
      pmtiles
      tiled_map_layer
      tilejson
      tms
      wms
      wmts
      xyz
    ]
  }

  @metadata_shown = ["mods", "fgdc", "iso19139", "html"]
  @webservices_shown = %w[
    wms
    tms
    wfs
    xyz
    wmts
    tilejson
    iiif
    feature_layer
    tiled_map_layer
    dynamic_map_layer
    image_map_layer
    cog
    pmtiles
  ]

  @display_notes_shown = {
    danger: DisplayNoteShownConfig.new(
      bootstrap_alert_class: "alert-danger",
      icon: "fire-solid",
      note_prefix: "Danger: "
    ),
    info: DisplayNoteShownConfig.new(
      bootstrap_alert_class: "alert-info",
      icon: "circle-info-solid",
      note_prefix: "Info: "
    ),
    tip: DisplayNoteShownConfig.new(
      bootstrap_alert_class: "alert-success",
      icon: "lightbulb-solid",
      note_prefix: "Tip: "
    ),
    warning: DisplayNoteShownConfig.new(
      bootstrap_alert_class: "alert-warning",
      icon: "triangle-exclamation-solid",
      note_prefix: "Warning: "
    )
  }

  @sidebar_static_map = ["iiif", "iiif_manifest"]
end

Instance Attribute Details

#display_notes_shownObject

Display Notes to display / Non-prefixed default bootstrap class is alert-secondary



22
23
24
# File 'lib/geoblacklight/configuration.rb', line 22

def display_notes_shown
  @display_notes_shown
end

#gbl_paramsObject

Non-search-field GeoBlacklight application permitted params



28
29
30
# File 'lib/geoblacklight/configuration.rb', line 28

def gbl_params
  @gbl_params
end

#help_textObject

Toggle the help text feature that offers users context



25
26
27
# File 'lib/geoblacklight/configuration.rb', line 25

def help_text
  @help_text
end

#metadata_shownObject

Metadata shown in tool panel



45
46
47
# File 'lib/geoblacklight/configuration.rb', line 45

def 
  @metadata_shown
end

#relationships_shownObject

Relationships to display



51
52
53
# File 'lib/geoblacklight/configuration.rb', line 51

def relationships_shown
  @relationships_shown
end

Enable catalog#show sidebar static map for items with the following viewer protocols



34
35
36
# File 'lib/geoblacklight/configuration.rb', line 34

def sidebar_static_map
  @sidebar_static_map
end

#webservices_shownObject

Web services shown in tool panel



48
49
50
# File 'lib/geoblacklight/configuration.rb', line 48

def webservices_shown
  @webservices_shown
end

#wms_paramsObject

WMS Parameters



31
32
33
# File 'lib/geoblacklight/configuration.rb', line 31

def wms_params
  @wms_params
end

Instance Method Details

#fieldsObject



132
133
134
# File 'lib/geoblacklight/configuration.rb', line 132

def fields
  @fields ||= FieldsConfig.new
end

#leaflet_optionsObject

Returns Leaflet plugin settings to pass to the viewer. @return



139
140
141
# File 'lib/geoblacklight/configuration.rb', line 139

def leaflet_options
  @leaflet_options ||= Geoblacklight::Configuration::LeafletConfig.new
end