Class: Geoblacklight::HglDownload Deprecated
- Inherits:
-
Download
- Object
- Download
- Geoblacklight::HglDownload
- Defined in:
- lib/geoblacklight/download/hgl_download.rb
Overview
Deprecated.
The Harvard Geospatial Library download integration is removed without replacement in GeoBlacklight 5.
Instance Method Summary collapse
- #get ⇒ Object
-
#initialize(document, email, options = {}) ⇒ HglDownload
constructor
A new instance of HglDownload.
Constructor Details
#initialize(document, email, options = {}) ⇒ HglDownload
Returns a new instance of HglDownload.
7 8 9 10 11 12 13 14 15 16 17 18 19 |
# File 'lib/geoblacklight/download/hgl_download.rb', line 7 def initialize(document, email, = {}) Geoblacklight.deprecation.warn( "Geoblacklight::HglDownload is deprecated without replacement and will be removed in GeoBlacklight 5" ) request_params = { "LayerName" => document[Settings.FIELDS.WXS_IDENTIFIER].sub(/^cite:/, ""), "UserEmail" => email } super(document, { request_params: request_params, service_type: "hgl" }.merge()) end |
Instance Method Details
#get ⇒ Object
21 22 23 |
# File 'lib/geoblacklight/download/hgl_download.rb', line 21 def get initiate_download end |